@@ -57,9 +57,9 @@ Entry::Entry() :
   m_cbVisible.signal_toggled().connect(slot(*this,&Entry::toggleVisibility));
   m_cbVisible.set_active(true);
 
-  m_bClose.signal_clicked().connect(slot(*this, &Entry::hide));
+  m_bClose.signal_clicked().connect(slot(*this, &Gtk::Widget::hide));
   m_vbox.pack_start(m_bClose);
-  m_bClose.set_flags(GTK_CAN_DEFAULT);
+  m_bClose.set_flags(Gtk::CAN_DEFAULT);
   m_bClose.grab_default();
   
   show_all();
